@@ -1,12 +1,14 @@
 package Class::Superclasses;
 
+# ABSTRACT: Find all (direct) superclasses of a class
+
 use strict;
 use warnings;
 
 use List::Util qw(first);
 use PPI;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 sub new{
     my ($class,$doc) = @_,
@@ -201,11 +203,11 @@ __END__
 
 =head1 NAME
 
-Class::Superclasses
+Class::Superclasses - Find all (direct) superclasses of a class
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -218,9 +220,12 @@ version 0.08
   
   print $_,"\n" for(@superclasses);
 
-=head1 NAME
-
-Class::Superclasses - Find all (direct) superclasses of a class
+  # or pass a scalar ref that contains the code
+  my $class_code = q~package Test; use base 'Baseclass';~;
+  $parser->document(\$class_code);
+  @superclasses = $parser->superclasses();
+  
+  print $_,"\n" for(@superclasses);
 
 =head2 DESCRIPTION
 
